@@ -37,8 +37,8 @@ sub create_ikc_responder
 {
     return if $ikc;
     new POE::Session( __PACKAGE__ , [qw(
-                      _start 
-                      request post call    
+                      _start _stop
+                      request post call raw_message
                       remote_error
                       register unregister default  
                       publish retract subscribe unsubscribe
@@ -58,6 +58,12 @@ sub _start
     $heap->{self}=$ikc;
 }
 
+
+sub _stop
+{
+#    warn "$_[HEAP] responder _stop\n";
+}
+
 #----------------------------------------------------
 # Foreign kernel called something here
 sub request
@@ -76,7 +82,7 @@ sub register
 }
 
 #----------------------------------------------------
-# Register foreign kernels when this disconnect (say)
+# Unregister foreign kernels when this disconnect (say)
 sub unregister
 {
     my($kernel, $heap, $channel, $names) = @_[KERNEL, HEAP, SENDER, ARG0];
@@ -93,7 +99,7 @@ sub default
 
 
 ##############################################################################
-## These are the 3 states that interact with the foreign kernel
+## These are the 4 states that interact with the foreign kernel
 
 #----------------------------------------------------
 # Send a request to the foreign kernel
@@ -112,15 +118,25 @@ sub call
                     @_[KERNEL, HEAP, SENDER, ARG0, ARG1, ARG2];
 
     $heap->{self}->call($to, $params, $rsvp, $sender);
+    return;
+}
+
+#----------------------------------------------------
+# Send a raw message over.  use at your own risk :)
+# This is useful for sending errors to remote ClientLite
+sub raw_message
+{
+    my($heap, $msg, $sender) = @_[HEAP, ARG0, ARG1];
+    $heap->{self}->send_msg($msg, $sender);
 }
 
 #----------------------------------------------------
 # Remote kernel had an error 
 sub remote_error
 {
-    my($heap, $params) = @_[HEAP, ARG0];
+    my($heap, $msg) = @_[HEAP, ARG0];
 
-    warn "Remote error: $params\n";
+    warn "Remote error: $msg\n";
 }
 
 ##############################################################################
@@ -371,6 +387,7 @@ sub default
 sub unregister
 {
     my($self, $channel, @todo)=@_;
+    my($kernel)=@{$self}{qw(poe_kernel)};
 
     my $name;
     while(@todo)
@@ -382,7 +399,7 @@ sub unregister
             push @todo, @{$self->{alias}{$name}};    
             $self->{'default'}='' if $self->{'default'} eq $name;
 
-            # TODO : close the channel
+            $kernel->post($self->{channel}{$name}, 'close');
             delete $self->{channel}{$name};
             delete $self->{alias}{$name};
 
@@ -414,6 +431,8 @@ sub unregister
 #----------------------------------------------------
 # Set a default foreign channel to send messages to
 
+
+
 #----------------------------------------------------
 # Internal function that does all the work of preparing a request to be sent
 sub send_msg
@@ -878,6 +897,7 @@ sub _start
     {
         $kernel->call(@$args);
     }
+    return;
 }
 
 sub _stop
