@@ -25,7 +25,7 @@ require Exporter;
 
 @ISA = qw(Exporter);
 @EXPORT = qw(create_ikc_server);
-$VERSION = '0.05';
+$VERSION = '0.06';
 
 sub DEBUG { 0 }
 
@@ -77,7 +77,7 @@ sub server_start
 sub server_error 
 {
     my ($operation, $errnum, $errstr) = @_[ARG0, ARG1, ARG2];
-    DEBUG && print "Server encountered $operation error $errnum: $errstr\n";
+    warn __PACKAGE__, " encountered $operation error $errnum: $errstr\n";
 }
 
 #----------------------------------------------------
